@@ -58,11 +58,11 @@ class EdgeFunction(
         description: typing.Optional[builtins.str] = None,
         environment: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
         environment_encryption: typing.Optional[aws_cdk.aws_kms.IKey] = None,
-        events: typing.Optional[typing.List[aws_cdk.aws_lambda.IEventSource]] = None,
+        events: typing.Optional[typing.Sequence[aws_cdk.aws_lambda.IEventSource]] = None,
         filesystem: typing.Optional[aws_cdk.aws_lambda.FileSystem] = None,
         function_name: typing.Optional[builtins.str] = None,
-        initial_policy: typing.Optional[typing.List[aws_cdk.aws_iam.PolicyStatement]] = None,
-        layers: typing.Optional[typing.List[aws_cdk.aws_lambda.ILayerVersion]] = None,
+        initial_policy: typing.Optional[typing.Sequence[aws_cdk.aws_iam.PolicyStatement]] = None,
+        layers: typing.Optional[typing.Sequence[aws_cdk.aws_lambda.ILayerVersion]] = None,
         log_retention: typing.Optional[aws_cdk.aws_logs.RetentionDays] = None,
         log_retention_retry_options: typing.Optional[aws_cdk.aws_lambda.LogRetentionRetryOptions] = None,
         log_retention_role: typing.Optional[aws_cdk.aws_iam.IRole] = None,
@@ -72,7 +72,7 @@ class EdgeFunction(
         reserved_concurrent_executions: typing.Optional[jsii.Number] = None,
         role: typing.Optional[aws_cdk.aws_iam.IRole] = None,
         security_group: typing.Optional[aws_cdk.aws_ec2.ISecurityGroup] = None,
-        security_groups: typing.Optional[typing.List[aws_cdk.aws_ec2.ISecurityGroup]] = None,
+        security_groups: typing.Optional[typing.Sequence[aws_cdk.aws_ec2.ISecurityGroup]] = None,
         timeout: typing.Optional[aws_cdk.core.Duration] = None,
         tracing: typing.Optional[aws_cdk.aws_lambda.Tracing] = None,
         vpc: typing.Optional[aws_cdk.aws_ec2.IVpc] = None,
@@ -170,7 +170,7 @@ class EdgeFunction(
         self,
         alias_name: builtins.str,
         *,
-        additional_versions: typing.Optional[typing.List[aws_cdk.aws_lambda.VersionWeight]] = None,
+        additional_versions: typing.Optional[typing.Sequence[aws_cdk.aws_lambda.VersionWeight]] = None,
         description: typing.Optional[builtins.str] = None,
         provisioned_concurrent_executions: typing.Optional[jsii.Number] = None,
         max_event_age: typing.Optional[aws_cdk.core.Duration] = None,
@@ -222,14 +222,14 @@ class EdgeFunction(
         bisect_batch_on_error: typing.Optional[builtins.bool] = None,
         enabled: typing.Optional[builtins.bool] = None,
         event_source_arn: typing.Optional[builtins.str] = None,
-        kafka_bootstrap_servers: typing.Optional[typing.List[builtins.str]] = None,
+        kafka_bootstrap_servers: typing.Optional[typing.Sequence[builtins.str]] = None,
         kafka_topic: typing.Optional[builtins.str] = None,
         max_batching_window: typing.Optional[aws_cdk.core.Duration] = None,
         max_record_age: typing.Optional[aws_cdk.core.Duration] = None,
         on_failure: typing.Optional[aws_cdk.aws_lambda.IEventSourceDlq] = None,
         parallelization_factor: typing.Optional[jsii.Number] = None,
         retry_attempts: typing.Optional[jsii.Number] = None,
-        source_access_configurations: typing.Optional[typing.List[aws_cdk.aws_lambda.SourceAccessConfiguration]] = None,
+        source_access_configurations: typing.Optional[typing.Sequence[aws_cdk.aws_lambda.SourceAccessConfiguration]] = None,
         starting_position: typing.Optional[aws_cdk.aws_lambda.StartingPosition] = None,
         tumbling_window: typing.Optional[aws_cdk.core.Duration] = None,
     ) -> aws_cdk.aws_lambda.EventSourceMapping:
@@ -752,11 +752,11 @@ class EdgeFunctionProps(aws_cdk.aws_lambda.FunctionProps):
         description: typing.Optional[builtins.str] = None,
         environment: typing.Optional[typing.Mapping[builtins.str, builtins.str]] = None,
         environment_encryption: typing.Optional[aws_cdk.aws_kms.IKey] = None,
-        events: typing.Optional[typing.List[aws_cdk.aws_lambda.IEventSource]] = None,
+        events: typing.Optional[typing.Sequence[aws_cdk.aws_lambda.IEventSource]] = None,
         filesystem: typing.Optional[aws_cdk.aws_lambda.FileSystem] = None,
         function_name: typing.Optional[builtins.str] = None,
-        initial_policy: typing.Optional[typing.List[aws_cdk.aws_iam.PolicyStatement]] = None,
-        layers: typing.Optional[typing.List[aws_cdk.aws_lambda.ILayerVersion]] = None,
+        initial_policy: typing.Optional[typing.Sequence[aws_cdk.aws_iam.PolicyStatement]] = None,
+        layers: typing.Optional[typing.Sequence[aws_cdk.aws_lambda.ILayerVersion]] = None,
         log_retention: typing.Optional[aws_cdk.aws_logs.RetentionDays] = None,
         log_retention_retry_options: typing.Optional[aws_cdk.aws_lambda.LogRetentionRetryOptions] = None,
         log_retention_role: typing.Optional[aws_cdk.aws_iam.IRole] = None,
@@ -766,7 +766,7 @@ class EdgeFunctionProps(aws_cdk.aws_lambda.FunctionProps):
         reserved_concurrent_executions: typing.Optional[jsii.Number] = None,
         role: typing.Optional[aws_cdk.aws_iam.IRole] = None,
         security_group: typing.Optional[aws_cdk.aws_ec2.ISecurityGroup] = None,
-        security_groups: typing.Optional[typing.List[aws_cdk.aws_ec2.ISecurityGroup]] = None,
+        security_groups: typing.Optional[typing.Sequence[aws_cdk.aws_ec2.ISecurityGroup]] = None,
         timeout: typing.Optional[aws_cdk.core.Duration] = None,
         tracing: typing.Optional[aws_cdk.aws_lambda.Tracing] = None,
         vpc: typing.Optional[aws_cdk.aws_ec2.IVpc] = None,
